@@ -1,4 +1,3 @@
-# pylint: disable=invalid-name
 """
 Observer-based V/Hz control for induction motor drives.
 
@@ -9,16 +8,14 @@ intermediate stator current reference.
 References
 ----------
 .. [1] Tiitinen, Hinkkanen, Harnefors, "Stable and passive observer-based V/Hz
-    control for induction motors," in Proc. IEEE ECCE, Detroit, MI, Oct. 2022.
+    control for induction motors," Proc. IEEE ECCE, Detroit, MI, Oct. 2022.
 
 """
 
 # %%
-from __future__ import annotations
-from collections.abc import Callable
+from typing import Callable
 from dataclasses import dataclass, field
 import numpy as np
-
 from motulator.control.common import Ctrl, PWM, RateLimiter
 from motulator.helpers import abc2complex, Bunch
 
@@ -56,7 +53,7 @@ class InductionMotorObsVHzCtrlPars:
     R_R: float = 2.1
     L_sgm: float = .021
     L_M: float = .224
-    p: int = 2
+    n_p: int = 2
 
 
 # %%
@@ -86,7 +83,7 @@ class InductionMotorVHzObsCtrl(Ctrl):
         self.alpha_f = pars.alpha_f
         self.alpha_r = pars.alpha_r
         self.alpha_psi = pars.alpha_psi
-        self.p = pars.p
+        self.n_p = pars.n_p
         self.k_tau = pars.k_tau
         self.i_s_max = pars.i_s_max
         self.slip_compensation = pars.slip_compensation
@@ -132,13 +129,13 @@ class InductionMotorVHzObsCtrl(Ctrl):
         w_r_ref = self.w_r_ref
 
         # Torque estimate (11c)
-        tau_M = 1.5*self.p*np.imag(i_s*np.conj(psi_R))
+        tau_M = 1.5*self.n_p*np.imag(i_s*np.conj(psi_R))
 
         # Slip frequency compensation (if enabled) for the low-pass filter.
         # Note, could also be based on the low-pass filtered torque.
         psi_R_sqr = np.abs(psi_R)**2
         if self.slip_compensation and psi_R_sqr > 0:
-            w_r = self.R_R*tau_M/(1.5*self.p*psi_R_sqr)
+            w_r = self.R_R*tau_M/(1.5*self.n_p*psi_R_sqr)
         else:
             w_r = 0
 
@@ -150,7 +147,7 @@ class InductionMotorVHzObsCtrl(Ctrl):
         w_s = w_s_ref - self.k_tau*(tau_M - tau_M_ref)
 
         # State feedback
-        u_s_ref, i_s_ref = self.state_feedback(i_s, psi_R, w_s)
+        u_s_ref = self.state_feedback(i_s, psi_R, w_s)
 
         # Duty ratios
         d_abc_ref, u_s_ref_lim = self.pwm.output(
@@ -194,7 +191,7 @@ class InductionMotorVHzObsCtrl(Ctrl):
         u_s_ref = (
             self.R_s*i_s_ref + 1j*w_s*self.psi_s_ref +
             self.L_sgm*self.alpha_psi*(i_s_ref - i_s))
-        return u_s_ref, i_s_ref
+        return u_s_ref
 
 
 # %%
@@ -221,7 +218,7 @@ class SensorlessFluxObserver:
 
     """
 
-    # pylint: disable=too-many-instance-attributes, too-few-public-methods
+    # pylint: disable=too-many-instance-attributes
     def __init__(self, pars):
         self.T_s = pars.T_s
         self.R_s = pars.R_s
@@ -251,7 +248,7 @@ class SensorlessFluxObserver:
         lambd = self.zeta_inf*np.abs(w_s) + .5*self.alpha
         # Observer gain (without the orthogonal projection which is
         # embedded into the state update)
-        g_o = 2*lambd*(self.alpha + 1j*self.w_m)/(self.alpha**2 + self.w_m**2)
+        g_o = 2*lambd/(self.alpha - 1j*self.w_m)
 
         # Time derivative of the stator current
         di_s = (i_s - self.i_s_old)/self.T_s
@@ -262,8 +259,7 @@ class SensorlessFluxObserver:
             (self.alpha - 1j*self.w_m)*self.psi_R - u_s)
 
         # Error signal
-        psi_R_sqr = np.abs(self.psi_R)**2
-        err = e*np.conj(self.psi_R)/psi_R_sqr if psi_R_sqr > 0 else 0
+        err = e/self.psi_R if np.abs(self.psi_R) > 0 else 0
 
         # Update the states
         self.w_m -= self.T_s*self.alpha_o*err.imag
