@@ -1,8 +1,6 @@
-# pylint: disable=invalid-name
 """Helper functions and classes."""
 
 # %%
-from __future__ import annotations
 from dataclasses import dataclass
 import numpy as np
 
@@ -74,12 +72,13 @@ class BaseValues:
     """
 
     # pylint: disable=too-many-instance-attributes
-    U_nom: float
-    I_nom: float
-    f_nom: float
-    P_nom: float
-    tau_nom: float
-    p: int
+    # Nominal values
+    U_nom: float  # Voltage (rms, line-line)
+    I_nom: float  # Current (rms)
+    f_nom: float  # Frequency
+    P_nom: float  # Power
+    tau_nom: float  # Torque
+    n_p: int  # Number of pole pairs
 
     def __post_init__(self):
         """Compute the base values."""
@@ -87,10 +86,10 @@ class BaseValues:
         self.i = np.sqrt(2)*self.I_nom
         self.w = 2*np.pi*self.f_nom
         self.psi = self.u/self.w
-        self.P = 1.5*self.u*self.i
+        self.p = 1.5*self.u*self.i
         self.Z = self.u/self.i
         self.L = self.Z/self.w
-        self.tau = self.p*self.P/self.w
+        self.tau = self.n_p*self.p/self.w
 
 
 # %%
@@ -112,7 +111,6 @@ class Sequence:
 
     """
 
-    # pylint: disable=too-few-public-methods
     def __init__(self, times, values, periodic=False):
         self.times = times
         self.values = values
@@ -143,7 +141,6 @@ class Sequence:
 class Step:
     """Step function."""
 
-    # pylint: disable=too-few-public-methods
     def __init__(self, step_time, step_value, initial_value=0):
         self.step_time = step_time
         self.step_value = step_value
